camelot.camelot.view.response_handler

Package camelot :: Package camelot :: Package view :: Module response_handler |
[hide private]
[frames] | no frames]

# Module response_handler

source code

QT Response handler class to be used when constructing a model thread. Construct this response handler within the GUI thread to have all responses being handled within the event loop of the GUI thread.

Classes | [hide private]
| ResponseHandler

Variables | [hide private]
| logger = `logging.getLogger('response_handler')`